==> MicroHs-0.10.3.0.tar.gz: MicroHs-0.10.3.0/lib/AllOfLib.hs <==
-- Copyright 2023,2024 Lennart Augustsson
-- See LICENSE file for full license.
module AllOfLib(main) where
-- Only used to save the compilation cache.
import Control.Applicative
import Control.Category
import Control.DeepSeq
import Control.Error
import Control.Exception
import Control.Exception.Internal
import Control.Monad
import Control.Monad.Fail
import Control.Monad.IO.Class
import Control.Monad.ST
import Control.Monad.ST_Type
import Data.Bits
import Data.Bool
import Data.Bool_Type
import Data.Bifoldable
import Data.Bifunctor
import Data.Bitraversable
import Data.Bounded
import Data.ByteString
import Data.Char
import Data.Char_Type
import Data.Complex
import Data.Constraint
import Data.Dynamic
import Data.Either
import Data.Enum
import Data.Eq
import Data.Fixed
import Data.FloatW
import Data.Floating
import Data.Foldable
import Data.Foldable1
import Data.Fractional
import Data.Function
import Data.Functor
import Data.Functor.Classes
import Data.Functor.Compose
import Data.Functor.Const
import Data.Functor.Contravariant
import Data.Functor.Identity
import Data.Functor.Product
import Data.Functor.Sum
import Data.Hashable
import Data.IOArray
import Data.IORef
import Data.Int
import Data.Int.IntN
import Data.Int.Instances
import Data.Integer
import Data.Integer_Type
import Data.Integral
import Data.Ix
import Data.Kind
import Data.List
import Data.List_Type
import Data.Maybe
import Data.Maybe_Type
import Data.Monoid
import Data.Monoid.Internal
import Data.Num
import Data.Ord
import Data.Orphans
import Data.Ordering_Type
import Data.Proxy
import Data.Ratio
import Data.Ratio_Type
import Data.Real
import Data.RealFloat
import Data.RealFrac
import Data.Records
import Data.Semigroup
import Data.STRef
import Data.String
import Data.Text
import Data.Traversable
import Data.Tuple
import Data.Tuple.Instances
import Data.Typeable
import Data.TypeLits
import Data.Version
import Data.Void
import Data.Word
import Data.ZipList
import Debug.Trace
import Foreign
import Foreign.C
import Foreign.C.Error
import Foreign.C.String
import Foreign.C.Types
import Foreign.ForeignPtr
import Foreign.Marshal
import Foreign.Marshal.Alloc
import Foreign.Marshal.Array
import Foreign.Marshal.Error
import Foreign.Marshal.Utils
import Foreign.Ptr
import Foreign.Storable
import GHC.Stack
import GHC.Types
import Numeric
import Numeric.FormatFloat
import Numeric.Natural
import Prelude
import Primitives
import System.Compress
import System.Console.GetOpt
--import System.Console.SimpleReadline
import System.Directory
import System.Environment
import System.Exit
import System.IO
import System.IO_Handle
import System.IO.Error
import System.IO.MD5
import System.IO.PrintOrRun
import System.IO.Serialize
import System.IO.TimeMilli
import System.Info
import System.Process
import Text.Printf
import Text.Read
import Text.Show
import Unsafe.Coerce

main :: IO ()
main = return ()

==> MicroHs-0.15.0.0.tar.gz: MicroHs-0.15.0.0/lib/AllOfLib.hs <==
-- Copyright 2023,2024 Lennart Augustsson
-- See LICENSE file for full license.
module AllOfLib(main) where
-- Only used to save the compilation cache.
import Control.Applicative
import Control.Category
import Control.Concurrent
import Control.Concurrent.Chan
import Control.Concurrent.MVar
import Control.Concurrent.QSem
import Control.Concurrent.QSemN
import Control.DeepSeq
import Control.DeepSeq.Class
import Control.Error
import Control.Exception
import Control.Exception.Internal
import Control.Monad
import Control.Monad.Fail
import Control.Monad.IO.Class
import Control.Monad.ST
import Control.Monad.ST_Type
import Data.Bits
import Data.Bool
import Data.Bool_Type
import Data.Bifoldable
import Data.Bifoldable1
import Data.Bifunctor
import Data.Bitraversable
import Data.Bounded
import Data.ByteString
import Data.ByteString.Builder
import Data.ByteString.Builder.Extra
import Data.ByteString.Char8
import Data.ByteString.Lazy
import Data.ByteString.Lazy.Char8
import Data.ByteString.Lazy.Internal
import Data.ByteString.Short.Internal
import Data.Char
import Data.Char_Type
import Data.Char.Unicode
import Data.Coerce
import Data.Complex
import Data.Constraint
import Data.Double
import Data.Dynamic
import Data.Either
import Data.Enum
import Data.Eq
import Data.Fixed
import Data.Float
import Data.Floating
import Data.Foldable
import Data.Foldable1
import Data.Fractional
import Data.Function
import Data.Functor
import Data.Functor.Classes
import Data.Functor.Compose
import Data.Functor.Const
import Data.Functor.Contravariant
import Data.Functor.Identity
import Data.Functor.Product
import Data.Functor.Sum
import Data.Hashable
import Data.Hashable.Class
import Data.Hashable.Lifted
import Data.IORef
import Data.Int
import Data.Int.Int8
import Data.Int.Int16
import Data.Int.Int32
import Data.Int.Int64
import Data.Integer
import Data.Integer_Type
import Data.Integral
import Data.Ix
import Data.Kind
import Data.List
import Data.List_Type
import Data.Maybe
import Data.Maybe_Type
import Data.Monoid
import Data.Monoid.Internal
import Data.Num
import Data.Ord
import Data.Orphans
import Data.Ordering_Type
import Data.Proxy
import Data.Ratio
import Data.Ratio_Type
import Data.Real
import Data.RealFloat
import Data.RealFrac
import Data.Records
import Data.Semigroup
import Data.STRef
import Data.String
import Data.Text
import Data.Text.Encoding
import Data.Text.IO
import Data.Text.Lazy
import Data.Text.Lazy.IO
import Data.Traversable
import Data.Tuple
import Data.Tuple.Instances
import Data.Type.Coercion
import Data.Type.Equality
import Data.Typeable
import Data.TypeLits
import Data.Unique
import Data.Version
import Data.Void
import Data.Word
import Data.Word.Word8
import Data.Word.Word16
import Data.Word.Word32
import Data.Word.Word64
import Data.ZipList
import Debug.Trace
import Foreign
import Foreign.C
import Foreign.C.Error
import Foreign.C.String
import Foreign.C.Types
import Foreign.ForeignPtr
import Foreign.ForeignPtr_Type
import Foreign.Marshal
import Foreign.Marshal.Alloc
import Foreign.Marshal.Array
import Foreign.Marshal.Error
import Foreign.Marshal.Utils
import Foreign.Ptr
import Foreign.StablePtr
import Foreign.Storable
import GHC.Generics
import Math.NumberTheory.Logarithms
import Numeric
import Numeric.FormatFloat
import Numeric.Natural
import Mhs.Arr
import Mhs.Array
import Mhs.Builtin
import Mhs.MutArr
import Mhs.MutUArr
import Mhs.UArr
import Prelude
import Primitives
import System.Compress
import System.Console.GetOpt
--import System.Console.SimpleReadline
import System.Directory
import System.Environment
import System.Exit
import System.IO
import System.IO.Base
import System.IO_Handle
import System.IO.Error
import System.IO.MD5
import System.IO.PrintOrRun
import System.IO.Serialize
import System.IO.StringHandle
import System.IO.TimeMilli
import System.Info
import System.Mem
import System.Mem.Weak
import System.Posix.Types
import System.Process
import System.RTS
import System.Timeout
import Text.Printf
import Text.Read
import Text.Show
import Unsafe.Coerce

main :: IO ()
main = return ()
